@@ -1,9 +1,24 @@
 package Catmandu::Zotero;
 
+our $VERSION = '0.03';
+
+1;
+__END__
+
 =head1 NAME
 
 Catmandu::Zotero - Catmandu modules for working with Zotero web
 
+=begin markdown
+
+# STATUS
+
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-Zotero.png)](https://travis-ci.org/LibreCat/Catmandu-Zotero)
+[![Coverage Status](https://coveralls.io/repos/LibreCat/Catmandu-Zotero/badge.png)](https://coveralls.io/r/LibreCat/Catmandu-Zotero)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/Catmandu-Zotero.png)](http://cpants.cpanauthors.org/dist/Catmandu-Zotero)
+
+=end markdown
+
 =head1 SYNOPSIS
 
   # From the command line
@@ -20,10 +35,6 @@ Catmandu::Zotero - Catmandu modules for working with Zotero web
 	   print "%s %s\n", $item->{_id} , $item->{title}->[0];
   });
 
-=cut
-
-our $VERSION = '0.02';
-
 =head1 MODULES
 
 =over
@@ -34,7 +45,7 @@ our $VERSION = '0.02';
 
 =head1 AUTHOR
 
-Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>
+Patrick Hochstenbach, C<patrick.hochstenbach at ugent.be>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -47,5 +58,3 @@ by the Free Software Foundation; or the Artistic License.
 See http://dev.perl.org/licenses/ for more information.
 
 =cut
-
-1;
\ No newline at end of file
